# -*- coding: utf-8 -*-
# Generated by Django 1.9 on 2015-12-08 15:36
from __future__ import unicode_literals

from django.db import migrations, models
import user_sessions.models


class Migration(migrations.Migration):

    dependencies = [
        ('user_sessions', '0001_initial'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='session',
            managers=[
                ('objects', user_sessions.models.SessionManager()),
            ],
        ),
        migrations.AlterField(
            model_name='session',
            name='ip',
            field=models.GenericIPAddressField(verbose_name='IP'),
        ),
    ]
