# -*- coding: utf-8 -*-
# Generated by Django 1.10.4 on 2016-12-05 15:16
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('user_sessions', '0002_auto_20151208_1536'),
    ]

    operations = [
        migrations.AlterField(
            model_name='session',
            name='ip',
            field=models.GenericIPAddressField(blank=True, null=True, verbose_name='IP'),
        ),
        migrations.AlterField(
            model_name='session',
            name='user_agent',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
